# nxs-analysis-tools

[![DOI](https://zenodo.org/badge/644189683.svg)](https://doi.org/10.5281/zenodo.15186359)
[![PyPI](https://img.shields.io/pypi/v/nxs-analysis-tools)](https://pypi.org/project/nxs-analysis-tools/)
[![Documentation Status](https://readthedocs.org/projects/nxs-analysis-tools/badge/?version=latest)](https://nxs-analysis-tools.readthedocs.io/en/latest/?badge=latest)

## Overview

nxs-analysis-tools provides a suite of tools for slicing (2D), cutting (1D), and transforming (_e.g._, symmetrization, interpolation, delta-PDF) nexus format (.nxs) scattering data.

View the documentation [here](https://nxs-analysis-tools.readthedocs.io/en/stable/).

## Installation

Install nxs-analysis-tools with ``pip``:

```{code-block} console
pip install nxs-analysis-tools
```

The source code can be downloaded from the nxs-analysis-tools Git repository:

```{code-block} console
git clone https://github.com/stevenjgomez/nxs-analysis-tools.git
```

## License

This project is licensed under the MIT License. If you find the nxs-analysis-tools package useful in your scientific publications, please cite the relevant DOI.

To cite the most recent version, use:

[![DOI](https://zenodo.org/badge/644189683.svg)](https://doi.org/10.5281/zenodo.15186359)

To cite all versions, use:

```
10.5281/zenodo.15186359
```
